==> cogent-1.3.1.tar.gz: cogent-1.3.1/cogent/parse/__init__.py <==
#!/usr/bin/env python

__all__ = ['aaindex',
           'agilent_microarray',
           'blast',
           'bpseq',
           'carnac',
           'cigar',
           'clustal',
           'cmfinder',
           'column',
           'comrna',
           'consan',
           'contrafold',
           'cove',
           'ct',
           'cut',
           'cutg',
           'dialign',
           'dynalign',
           'ebi',
           'fasta',
           'foldalign',
           'gbseq',
           'gcg',
           'genbank',
           'gff',
           'ilm',
           'knetfold',
           'locuslink',
           'macsim',
           'mage',
           'meme',
           'mfold',
           'ncbi_taxonomy',
           'newick',
           'nexus',
           'nupack',
           'paml',
           'paml_matrix',
           'pfold',
           'phylip',
           'pknotsrg',
           'rdb',
           'record',
           'record_finder',
           'rfam',
           'rna_fold',
           'rnaalifold',
           'rnaforester',
           'rnashapes',
           'rnaview',
           'sequence',
           'sfold',
           'sprinzl',
           'table',
           'tinyseq',
           'tree',
           'tree_xml',
           'unafold',
           'unigene']
  
__author__ = ""
__copyright__ = "Copyright 2007-2009, The Cogent Project"
__credits__ = ["Gavin Huttley", "Peter Maxwell", "Rob Knight",
                    "Catherine Lozupone", "Jeremy Widmann", "Matthew Wakefield",
                    "Sandra Smit", "Greg Caporaso", "Zongzhi Liu", 
                    "Micah Hamady", "Jason Carnes", "Raymond Sammut", 
                    "Hua Ying", "Andrew Butterfield"]
__license__ = "GPL"
__version__ = "1.3.1"
__maintainer__ = "Rob Knight"
__email__ = "rob@spot.colorado.edu"
__status__ = "Production"

==> cogent-1.4.tar.gz: cogent-1.4/cogent/parse/__init__.py <==
#!/usr/bin/env python

__all__ = ['aaindex',
           'agilent_microarray',
           'blast',
           'bpseq',
           'carnac',
           'cigar',
           'clustal',
           'cmfinder',
           'column',
           'comrna',
           'consan',
           'contrafold',
           'cove',
           'ct',
           'cut',
           'cutg',
           'dialign',
           'dynalign',
           'ebi',
           'fasta',
           'foldalign',
           'gbseq',
           'gcg',
           'genbank',
           'gff',
           'ilm',
           'knetfold',
           'locuslink',
           'macsim',
           'mage',
           'meme',
           'mfold',
           'ncbi_taxonomy',
           'newick',
           'nexus',
           'nupack',
           'paml',
           'paml_matrix',
           'pdb',
           'pfold',
           'phylip',
           'pknotsrg',
           'rdb',
           'record',
           'record_finder',
           'rfam',
           'rna_fold',
           'rnaalifold',
           'rnaforester',
           'rnashapes',
           'rnaview',
           'sequence',
           'sfold',
           'sprinzl',
           'table',
           'tinyseq',
           'tree',
           'tree_xml',
           'unafold',
           'unigene']

__author__ = ""
__copyright__ = "Copyright 2007-2009, The Cogent Project"
__credits__ = ["Gavin Huttley", "Peter Maxwell", "Rob Knight",
                    "Catherine Lozupone", "Jeremy Widmann", "Matthew Wakefield",
                    "Sandra Smit", "Greg Caporaso", "Zongzhi Liu",
                    "Micah Hamady", "Jason Carnes", "Raymond Sammut",
                    "Hua Ying", "Andrew Butterfield", "Marcin Cieslik"]
__license__ = "GPL"
__version__ = "1.4"
__maintainer__ = "Rob Knight"
__email__ = "rob@spot.colorado.edu"
__status__ = "Production"
